PDFs that are binned such as template PDFs or convert from and to unbinned PDFs.

.. autosummary::
    :toctree: _generated/binned_pdf

    zfit.pdf.HistogramPDF
    zfit.pdf.BinwiseScaleModifier
    zfit.pdf.BinnedFromUnbinnedPDF
    zfit.pdf.SplineMorphingPDF
    zfit.pdf.BinnedSumPDF
    zfit.pdf.SplinePDF
    zfit.pdf.UnbinnedFromBinnedPDF
